import { useRouter } from 'next/router';
import { useEffect } from 'react';
import { getToken } from '../utils/login';

/**
 * Performs redirect when user is unauthenticated.
 * @param path path where to redirect
 * @returns redirecting?
 */
const useUnauthRedirect = (path: string): boolean => {
    const router = useRouter();
    let tokenEmpty = false;
    useEffect(() => {
        async function checkToken() {
            const empty = (await getToken()) === '';
            if (tokenEmpty) {
                router.push(path);
            }
            // eslint-disable-next-line react-hooks/exhaustive-deps
            tokenEmpty = empty;
        }
        checkToken();
    }, [path, router]);

    return tokenEmpty;
};

export default useUnauthRedirect;
